@@ -5,6 +5,7 @@ import numpy as np
 def variational_error(func,params,error,param_id):
     
     values = []
+    defualt = params # stores the default parameters
      #converts error and param_id to lists if only a single value is provided
         
     if type(error) != list and type(error) != np.array:
@@ -17,15 +18,15 @@ def variational_error(func,params,error,param_id):
         values.append(params[i]) 
         params[i] = values[param_id.index(i)] + error[param_id.index(i)]
         
-    # calculates high value of function
-    up_calc = np.abs(func(*params))
+    # calculates high error of function
+    up_calc = np.abs(func(*params)-func(*defualt)) 
     
     # subtracts error from each value spesified in param_id
     for i in param_id:
         params[i] = values[param_id.index(i)] - error[param_id.index(i)]
     
-    # calculates low value of function
-    down_calc = np.abs(func(*params))
+    # calculates low eror of function
+    down_calc = np.abs(func(*params)-func(*defualt))
     
     #returns the average of the difference between the high and low values
-    return np.abs(up_calc - down_calc)/2
+    return np.abs(up_calc + down_calc)/2
